==> chaosmesh-model-5.1.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/RawTrafficControlFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Long;
import java.lang.Object;
import java.util.Map;

public interface RawTrafficControlFluent<A extends RawTrafficControlFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildBandwidth instead.
 * @return The buildable object.
 */
@Deprecated public BandwidthSpec getBandwidth();
    public BandwidthSpec buildBandwidth();
    public A withBandwidth(BandwidthSpec bandwidth);
    public Boolean hasBandwidth();
    public A withNewBandwidth(Integer buffer,Integer limit,Long minburst,Long peakrate,String rate);
    public RawTrafficControlFluent.BandwidthNested<A> withNewBandwidth();
    public RawTrafficControlFluent.BandwidthNested<A> withNewBandwidthLike(BandwidthSpec item);
    public RawTrafficControlFluent.BandwidthNested<A> editBandwidth();
    public RawTrafficControlFluent.BandwidthNested<A> editOrNewBandwidth();
    public RawTrafficControlFluent.BandwidthNested<A> editOrNewBandwidthLike(BandwidthSpec item);
    
/**
 * This method has been deprecated, please use method buildCorrupt instead.
 * @return The buildable object.
 */
@Deprecated public CorruptSpec getCorrupt();
    public CorruptSpec buildCorrupt();
    public A withCorrupt(CorruptSpec corrupt);
    public Boolean hasCorrupt();
    public A withNewCorrupt(String correlation,String corrupt);
    public RawTrafficControlFluent.CorruptNested<A> withNewCorrupt();
    public RawTrafficControlFluent.CorruptNested<A> withNewCorruptLike(CorruptSpec item);
    public RawTrafficControlFluent.CorruptNested<A> editCorrupt();
    public RawTrafficControlFluent.CorruptNested<A> editOrNewCorrupt();
    public RawTrafficControlFluent.CorruptNested<A> editOrNewCorruptLike(CorruptSpec item);
    
/**
 * This method has been deprecated, please use method buildDelay instead.
 * @return The buildable object.
 */
@Deprecated public DelaySpec getDelay();
    public DelaySpec buildDelay();
    public A withDelay(DelaySpec delay);
    public Boolean hasDelay();
    public RawTrafficControlFluent.DelayNested<A> withNewDelay();
    public RawTrafficControlFluent.DelayNested<A> withNewDelayLike(DelaySpec item);
    public RawTrafficControlFluent.DelayNested<A> editDelay();
    public RawTrafficControlFluent.DelayNested<A> editOrNewDelay();
    public RawTrafficControlFluent.DelayNested<A> editOrNewDelayLike(DelaySpec item);
    
/**
 * This method has been deprecated, please use method buildDuplicate instead.
 * @return The buildable object.
 */
@Deprecated public DuplicateSpec getDuplicate();
    public DuplicateSpec buildDuplicate();
    public A withDuplicate(DuplicateSpec duplicate);
    public Boolean hasDuplicate();
    public A withNewDuplicate(String correlation,String duplicate);
    public RawTrafficControlFluent.DuplicateNested<A> withNewDuplicate();
    public RawTrafficControlFluent.DuplicateNested<A> withNewDuplicateLike(DuplicateSpec item);
    public RawTrafficControlFluent.DuplicateNested<A> editDuplicate();
    public RawTrafficControlFluent.DuplicateNested<A> editOrNewDuplicate();
    public RawTrafficControlFluent.DuplicateNested<A> editOrNewDuplicateLike(DuplicateSpec item);
    public String getIpset();
    public A withIpset(String ipset);
    public Boolean hasIpset();
    public A withNewIpset(String arg1);
    public A withNewIpset(StringBuilder arg1);
    public A withNewIpset(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildLoss instead.
 * @return The buildable object.
 */
@Deprecated public LossSpec getLoss();
    public LossSpec buildLoss();
    public A withLoss(LossSpec loss);
    public Boolean hasLoss();
    public A withNewLoss(String correlation,String loss);
    public RawTrafficControlFluent.LossNested<A> withNewLoss();
    public RawTrafficControlFluent.LossNested<A> withNewLossLike(LossSpec item);
    public RawTrafficControlFluent.LossNested<A> editLoss();
    public RawTrafficControlFluent.LossNested<A> editOrNewLoss();
    public RawTrafficControlFluent.LossNested<A> editOrNewLossLike(LossSpec item);
    public String getSource();
    public A withSource(String source);
    public Boolean hasSource();
    public A withNewSource(String arg1);
    public A withNewSource(StringBuilder arg1);
    public A withNewSource(StringBuffer arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);
    public interface BandwidthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BandwidthSpecFluent<RawTrafficControlFluent.BandwidthNested<N>> {

            public N and();
            public N endBandwidth();    }


    public interface CorruptNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CorruptSpecFluent<RawTrafficControlFluent.CorruptNested<N>> {

            public N and();
            public N endCorrupt();    }


    public interface DelayNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DelaySpecFluent<RawTrafficControlFluent.DelayNested<N>> {

            public N and();
            public N endDelay();    }


    public interface DuplicateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DuplicateSpecFluent<RawTrafficControlFluent.DuplicateNested<N>> {

            public N and();
            public N endDuplicate();    }


    public interface LossNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LossSpecFluent<RawTrafficControlFluent.LossNested<N>> {

            public N and();
            public N endLoss();    }


}

==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/RawTrafficControlFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Long;
import java.lang.Object;
import java.util.Map;

public interface RawTrafficControlFluent<A extends RawTrafficControlFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildBandwidth instead.
 * @return The buildable object.
 */
@Deprecated public BandwidthSpec getBandwidth();
    public BandwidthSpec buildBandwidth();
    public A withBandwidth(BandwidthSpec bandwidth);
    public Boolean hasBandwidth();
    public A withNewBandwidth(Integer buffer,Integer limit,Long minburst,Long peakrate,String rate);
    public RawTrafficControlFluent.BandwidthNested<A> withNewBandwidth();
    public RawTrafficControlFluent.BandwidthNested<A> withNewBandwidthLike(BandwidthSpec item);
    public RawTrafficControlFluent.BandwidthNested<A> editBandwidth();
    public RawTrafficControlFluent.BandwidthNested<A> editOrNewBandwidth();
    public RawTrafficControlFluent.BandwidthNested<A> editOrNewBandwidthLike(BandwidthSpec item);
    
/**
 * This method has been deprecated, please use method buildCorrupt instead.
 * @return The buildable object.
 */
@Deprecated public CorruptSpec getCorrupt();
    public CorruptSpec buildCorrupt();
    public A withCorrupt(CorruptSpec corrupt);
    public Boolean hasCorrupt();
    public A withNewCorrupt(String correlation,String corrupt);
    public RawTrafficControlFluent.CorruptNested<A> withNewCorrupt();
    public RawTrafficControlFluent.CorruptNested<A> withNewCorruptLike(CorruptSpec item);
    public RawTrafficControlFluent.CorruptNested<A> editCorrupt();
    public RawTrafficControlFluent.CorruptNested<A> editOrNewCorrupt();
    public RawTrafficControlFluent.CorruptNested<A> editOrNewCorruptLike(CorruptSpec item);
    
/**
 * This method has been deprecated, please use method buildDelay instead.
 * @return The buildable object.
 */
@Deprecated public DelaySpec getDelay();
    public DelaySpec buildDelay();
    public A withDelay(DelaySpec delay);
    public Boolean hasDelay();
    public RawTrafficControlFluent.DelayNested<A> withNewDelay();
    public RawTrafficControlFluent.DelayNested<A> withNewDelayLike(DelaySpec item);
    public RawTrafficControlFluent.DelayNested<A> editDelay();
    public RawTrafficControlFluent.DelayNested<A> editOrNewDelay();
    public RawTrafficControlFluent.DelayNested<A> editOrNewDelayLike(DelaySpec item);
    
/**
 * This method has been deprecated, please use method buildDuplicate instead.
 * @return The buildable object.
 */
@Deprecated public DuplicateSpec getDuplicate();
    public DuplicateSpec buildDuplicate();
    public A withDuplicate(DuplicateSpec duplicate);
    public Boolean hasDuplicate();
    public A withNewDuplicate(String correlation,String duplicate);
    public RawTrafficControlFluent.DuplicateNested<A> withNewDuplicate();
    public RawTrafficControlFluent.DuplicateNested<A> withNewDuplicateLike(DuplicateSpec item);
    public RawTrafficControlFluent.DuplicateNested<A> editDuplicate();
    public RawTrafficControlFluent.DuplicateNested<A> editOrNewDuplicate();
    public RawTrafficControlFluent.DuplicateNested<A> editOrNewDuplicateLike(DuplicateSpec item);
    public String getIpset();
    public A withIpset(String ipset);
    public Boolean hasIpset();
    public A withNewIpset(StringBuilder arg1);
    public A withNewIpset(int[] arg1,int arg2,int arg3);
    public A withNewIpset(char[] arg1);
    public A withNewIpset(StringBuffer arg1);
    public A withNewIpset(byte[] arg1,int arg2);
    public A withNewIpset(byte[] arg1);
    public A withNewIpset(char[] arg1,int arg2,int arg3);
    public A withNewIpset(byte[] arg1,int arg2,int arg3);
    public A withNewIpset(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewIpset(String arg1);
    
/**
 * This method has been deprecated, please use method buildLoss instead.
 * @return The buildable object.
 */
@Deprecated public LossSpec getLoss();
    public LossSpec buildLoss();
    public A withLoss(LossSpec loss);
    public Boolean hasLoss();
    public A withNewLoss(String correlation,String loss);
    public RawTrafficControlFluent.LossNested<A> withNewLoss();
    public RawTrafficControlFluent.LossNested<A> withNewLossLike(LossSpec item);
    public RawTrafficControlFluent.LossNested<A> editLoss();
    public RawTrafficControlFluent.LossNested<A> editOrNewLoss();
    public RawTrafficControlFluent.LossNested<A> editOrNewLossLike(LossSpec item);
    public String getSource();
    public A withSource(String source);
    public Boolean hasSource();
    public A withNewSource(StringBuilder arg1);
    public A withNewSource(int[] arg1,int arg2,int arg3);
    public A withNewSource(char[] arg1);
    public A withNewSource(StringBuffer arg1);
    public A withNewSource(byte[] arg1,int arg2);
    public A withNewSource(byte[] arg1);
    public A withNewSource(char[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSource(String arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(StringBuilder arg1);
    public A withNewType(int[] arg1,int arg2,int arg3);
    public A withNewType(char[] arg1);
    public A withNewType(StringBuffer arg1);
    public A withNewType(byte[] arg1,int arg2);
    public A withNewType(byte[] arg1);
    public A withNewType(char[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewType(String arg1);
    public interface BandwidthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BandwidthSpecFluent<RawTrafficControlFluent.BandwidthNested<N>> {

            public N and();
            public N endBandwidth();    }


    public interface CorruptNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CorruptSpecFluent<RawTrafficControlFluent.CorruptNested<N>> {

            public N and();
            public N endCorrupt();    }


    public interface DelayNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DelaySpecFluent<RawTrafficControlFluent.DelayNested<N>> {

            public N and();
            public N endDelay();    }


    public interface DuplicateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DuplicateSpecFluent<RawTrafficControlFluent.DuplicateNested<N>> {

            public N and();
            public N endDuplicate();    }


    public interface LossNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LossSpecFluent<RawTrafficControlFluent.LossNested<N>> {

            public N and();
            public N endLoss();    }


}
